import { Api } from "./Api";
import { CallbackQueryContext } from "./contexts/CallbackQueryContext";
import { MessageContext } from "./contexts/MessageContext";
import { IMessage } from "./types/IMessage";
import { IUpdateResult } from "./types/IUpdate";
declare type EventContexts = {
    message: MessageContext;
    callback_query: CallbackQueryContext;
};
export declare type TextMatch = string | string[] | RegExp;
export declare type UpdateHandlerFn<TUpdate> = (context: TUpdate, next: () => void) => any;
export declare type UpdateHandlerErrorListener = (err: unknown) => Promise<void>;
export declare class UpdateHandler {
    private readonly api;
    constructor(api: Api);
    private contextCtorStorage;
    private baseHandler;
    private updates;
    private errorListener;
    onError(listener: UpdateHandlerErrorListener): void;
    handle(update: IUpdateResult): Promise<void>;
    private handleUpdate;
    private conversation;
    implementConversations(): void;
    implementDecorators(...decoratedHandlers: Record<string, any>[]): void;
    setContext<TEvent extends keyof EventContexts, TContext extends EventContexts[TEvent]>(event: TEvent, ctor: new (...args: any[]) => TContext): void;
    use(handler: UpdateHandlerFn<IUpdateResult>): void;
    onUpdate<TUpdate>(updateKind: string, handler: UpdateHandlerFn<TUpdate>, skipConvertingToContext?: boolean): void;
    hearCallbackQuery<TContext extends CallbackQueryContext>(match: TextMatch, handler: UpdateHandlerFn<TContext>): void;
    hearCommand<TContext extends MessageContext>(match: TextMatch, handler: UpdateHandlerFn<TContext>): void;
    private hearEvent;
    onMessageEvent<TContext extends MessageContext>(event: keyof TContext | keyof IMessage, handler: UpdateHandlerFn<TContext>): void;
}
export {};
