"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.CommandInfo = exports.CommandInfoDecoratorMetadata = void 0;
const utils_1 = require("../utils");
class CommandInfoDecoratorMetadata {
    constructor() {
        this.storage = [];
    }
    add(command, description, lang = null, scope) {
        this.storage.push({
            lang,
            command,
            description,
            scope: scope !== null && scope !== void 0 ? scope : { type: "default" },
        });
    }
    implement(cmdList, instance) {
        let initLanguage = cmdList.getLang();
        let initScope = cmdList.getScope();
        for (let cmd of this.storage) {
            cmdList.setLanguage(this.parseCommandParameter(cmd.lang, instance));
            cmdList.setScope(cmd.scope.type, (0, utils_1.filterObjectByKey)(cmd.scope, k => k !== "type"));
            cmdList.add(this.parseCommandParameter(cmd.command, instance), this.parseCommandParameter(cmd.description, instance));
        }
        cmdList.setLanguage(initLanguage);
        cmdList.setScope(initScope.type, (0, utils_1.filterObjectByKey)(initScope, k => k !== "type"));
    }
    parseCommandParameter(param, arg) {
        return typeof param === "function" ? param(arg) : param;
    }
}
exports.CommandInfoDecoratorMetadata = CommandInfoDecoratorMetadata;
function CommandInfo(command, description, language, scope) {
    return target => {
        if (!target.constructor.prototype.__tgCommandInfo)
            target.constructor.prototype.__tgCommandInfo =
                new CommandInfoDecoratorMetadata();
        let metadata = target.constructor.prototype.__tgCommandInfo;
        metadata.add(command, description, language, scope);
        return target;
    };
}
exports.CommandInfo = CommandInfo;
