"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.BotCommandList = void 0;
const utils_1 = require("../utils");
class BotCommandList {
    constructor() {
        this.commands = [];
        this.currentLang = "";
        this.currentScope = { type: "default" };
    }
    add(command, description) {
        this.commands.push({
            command,
            description,
            lang: this.currentLang,
            scope: this.currentScope,
        });
        return this;
    }
    get() {
        let commandGroups = (0, utils_1.groupByKey)(this.commands, "lang");
        return commandGroups.map(cmdGroup => ({
            language: cmdGroup.key,
            commands: (0, utils_1.groupByKey)(cmdGroup.values, "scope").map(cmd => ({
                scope: cmd.key,
                bodies: cmd.values.map(body => ({
                    command: body.command,
                    description: body.description,
                })),
            })),
        }));
    }
    getLang() {
        return this.currentLang;
    }
    getScope() {
        return this.currentScope;
    }
    implementDecorators(...decoratedHandlers) {
        var _a, _b;
        for (let handler of decoratedHandlers) {
            let metadata = (_b = (_a = handler === null || handler === void 0 ? void 0 : handler.constructor) === null || _a === void 0 ? void 0 : _a.prototype) === null || _b === void 0 ? void 0 : _b.__tgCommandInfo;
            if (!metadata)
                continue;
            metadata.implement(this, handler);
        }
        return this;
    }
    setScope(type, params) {
        this.currentScope = Object.assign({ type }, (params !== null && params !== void 0 ? params : {}));
        return this;
    }
    resetScope() {
        this.currentScope = { type: "default" };
        return this;
    }
    setLanguage(lang) {
        this.currentLang = lang;
        return this;
    }
    resetLanguage() {
        this.setLanguage(null);
        return this;
    }
}
exports.BotCommandList = BotCommandList;
