/// <reference types="node" />
/// <reference types="node" />
import { Api } from "../Api";
import { ReadStream } from "fs";
import { Message, Attachment } from "../models";
import { ChatContext } from "./ChatContext";
import * as Params from "../types/params";
import { IMessage, IAttachment, IAudioAttachment, IDocumentAttachment, IPhotoAttachment, IVideoAttachment, IVoiceAttachment, IKeyboard, IKeyboardInline } from "../types";
import { AttachmentType, IAttachmentSendParams } from "../types/params";
import { Conversation } from "../converstations/Conversation";
import { ConversationOptions } from "../converstations";
declare type AttachmentSource<TAttachment extends IAttachment> = string | Buffer | ReadStream | Attachment<TAttachment>;
declare type SendMessageParams = string | ({
    text: string;
} & Partial<Params.IMessageSendParams>);
export declare class MessageContext extends Message {
    private readonly api;
    private readonly conversation?;
    match: string[];
    chat: ChatContext;
    constructor(api: Api, source: IMessage, conversation?: Conversation);
    pin(id?: number, disableNotification?: boolean): Promise<boolean>;
    unpin(id?: number): Promise<boolean>;
    unpinAll(): Promise<boolean>;
    ask(options?: ConversationOptions): Promise<import("../converstations").ConversationAnswer>;
    editText(text?: string, params?: Partial<Params.ITextEditParams | Params.ICaptionEditParams>): Promise<Message>;
    editKeyboard(keyboard: IKeyboard | IKeyboardInline, params?: Partial<Params.IBaseEditParams>): Promise<Message>;
    delete(msgId?: number): Promise<boolean>;
    replyMessage(params: SendMessageParams): Promise<Message>;
    sendMessage(params: SendMessageParams): Promise<Message>;
    readonly replyVoice: (source: AttachmentSource<IVoiceAttachment>, params: Partial<IAttachmentSendParams> | string) => Promise<Message>;
    readonly replyVideo: (source: AttachmentSource<IVideoAttachment>, params: Partial<IAttachmentSendParams> | string) => Promise<Message>;
    readonly replyAudio: (source: AttachmentSource<IAudioAttachment>, params: Partial<IAttachmentSendParams> | string) => Promise<Message>;
    readonly replyPhoto: (source: AttachmentSource<IPhotoAttachment>, params: Partial<IAttachmentSendParams> | string) => Promise<Message>;
    readonly replyDocument: (source: AttachmentSource<IDocumentAttachment>, params: Partial<IAttachmentSendParams> | string) => Promise<Message>;
    readonly sendVoice: (source: AttachmentSource<IVoiceAttachment>, params: Partial<IAttachmentSendParams> | string) => Promise<Message>;
    readonly sendVideo: (source: AttachmentSource<IVideoAttachment>, params: Partial<IAttachmentSendParams> | string) => Promise<Message>;
    readonly sendAudio: (source: AttachmentSource<IAudioAttachment>, params: Partial<IAttachmentSendParams> | string) => Promise<Message>;
    readonly sendPhoto: (source: AttachmentSource<IPhotoAttachment>, params: Partial<IAttachmentSendParams> | string) => Promise<Message>;
    readonly sendDocument: (source: AttachmentSource<IDocumentAttachment>, params: Partial<IAttachmentSendParams> | string) => Promise<Message>;
    private sendAttachWithCaption;
    attach<TAttachmentType extends AttachmentType>(type: TAttachmentType, source: AttachmentSource<any>, params?: Partial<Params.IAttachmentSendParams>): Promise<Message>;
    private reply;
    private send;
    private execute;
}
export {};
