"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.CallbackQuery = exports.Event = exports.Update = exports.Use = exports.Command = exports.UpdateHandlerDecoratorMetadata = void 0;
class UpdateHandlerDecoratorMetadata {
    constructor() {
        this.storage = {};
    }
    add(method, ...args) {
        if (!this.storage.hasOwnProperty(method))
            this.storage[method] = [];
        this.storage[method].push(args);
    }
    implement(handler, instance) {
        for (let [method, metadata] of Object.entries(this.storage))
            for (let args of metadata)
                handler[method](...args.map((arg) => typeof arg === "function" ? arg.bind(instance) : arg));
    }
}
exports.UpdateHandlerDecoratorMetadata = UpdateHandlerDecoratorMetadata;
function injectMetadata(obj) {
    if (!obj.constructor.prototype.__tgHandlerMetadata)
        obj.constructor.prototype.__tgHandlerMetadata =
            new UpdateHandlerDecoratorMetadata();
    return obj.constructor.prototype.__tgHandlerMetadata;
}
function Command(pattern) {
    return (target, _, descriptor) => {
        injectMetadata(target).add("hearCommand", pattern, descriptor.value);
        return target;
    };
}
exports.Command = Command;
function Use() {
    return (target, _, descriptor) => {
        injectMetadata(target).add("use", descriptor.value);
        return target;
    };
}
exports.Use = Use;
function Update(updateKind, skipConvertingToContext = false) {
    return (target, _, descriptor) => {
        injectMetadata(target).add("onUpdate", updateKind, descriptor.value, skipConvertingToContext);
        return target;
    };
}
exports.Update = Update;
function Event(event) {
    return (target, _, descriptor) => {
        injectMetadata(target).add("onMessageEvent", event, descriptor.value);
        return target;
    };
}
exports.Event = Event;
function CallbackQuery(pattern) {
    return (target, prop, descriptor) => {
        injectMetadata(target).add("hearCallbackQuery", pattern, descriptor.value);
        return target;
    };
}
exports.CallbackQuery = CallbackQuery;
