"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.KeyboardBuilder = exports.InlineKeyboardBuilder = exports.BaseKeyboardBuilder = void 0;
const Button_1 = require("./Button");
class BaseKeyboardBuilder {
    constructor() {
        this.buttons = [];
    }
    add(btn) {
        let lastRow = this.buttons.length - 1;
        if (!this.buttons[lastRow] || this.buttons[lastRow].length >= 8) {
            this.wrap();
            lastRow++;
        }
        this.buttons[lastRow].push(btn);
        return this;
    }
    wrap() {
        this.buttons.push([]);
        return this;
    }
    clear() {
        this.buttons = [];
    }
}
exports.BaseKeyboardBuilder = BaseKeyboardBuilder;
class InlineKeyboardBuilder extends BaseKeyboardBuilder {
    createButton(...args) {
        return this.add(new Button_1.InlineButton(...args));
    }
    build() {
        return {
            reply_markup: {
                inline_keyboard: this.buttons.map(row => row.map(btn => btn.toObject())),
            },
        };
    }
}
exports.InlineKeyboardBuilder = InlineKeyboardBuilder;
class KeyboardBuilder extends BaseKeyboardBuilder {
    constructor() {
        super(...arguments);
        this.additionalOptions = {};
    }
    setResize(state = true) {
        this.additionalOptions["resize_keyboard"] = state;
        return this;
    }
    setOneTime(state = true) {
        this.additionalOptions["one_time_keyboard"] = state;
        return this;
    }
    setSelective(state = true) {
        this.additionalOptions["selective"] = state;
        return this;
    }
    setPlaceholder(text) {
        this.additionalOptions["input_field_placeholder"] = text.slice(0, 63);
        return this;
    }
    createButton(...args) {
        return this.add(new Button_1.Button(...args));
    }
    build() {
        return {
            reply_markup: Object.assign({ keyboard: this.buttons.map(row => row.map(btn => btn.toObject())) }, this.additionalOptions),
        };
    }
    static remove(remove = true, selective = false) {
        return JSON.stringify({
            remove_keyboard: remove,
            selective,
        });
    }
}
exports.KeyboardBuilder = KeyboardBuilder;
