"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Polling = void 0;
const debug = require("debug");
const EventTransport_1 = require("./EventTransport");
class Polling extends EventTransport_1.EventTransport {
    constructor() {
        super(...arguments);
        this.log = debug("tg-io:polling");
    }
    async start(handler) {
        if (this.state === EventTransport_1.EventTransportState.Working) {
            return;
        }
        this.log("started");
        return new Promise((resolve, reject) => {
            this.handleUpdates(handler, resolve, reject).catch(reject);
        });
    }
    async handleUpdates(handler, onstop, onerror) {
        var _a;
        let offset;
        this.state = EventTransport_1.EventTransportState.Working;
        while (this.state === EventTransport_1.EventTransportState.Working) {
            let updates = (await this.api.callMethod("getUpdates", offset ? { offset } : {}));
            this.log(`updates chunk offset=${offset} ok=${updates.ok} count=${updates.result.length}`);
            let lastUpdateId = (_a = updates.result.at(-1)) === null || _a === void 0 ? void 0 : _a.update_id;
            if (lastUpdateId) {
                offset = lastUpdateId + 1;
            }
            Promise.all(updates.result.map(handler.handle.bind(handler))).catch(onerror);
        }
        onstop();
    }
    stop() {
        if (this.state !== EventTransport_1.EventTransportState.Working)
            return;
        this.log("stopped");
        this.state = EventTransport_1.EventTransportState.Stopped;
    }
}
exports.Polling = Polling;
