"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Middleware = exports.MiddlewareToken = void 0;
const crypto_1 = require("crypto");
class MiddlewareToken {
    constructor() {
        this.passingState = true;
    }
    next() {
        this.passingState = true;
    }
    async complete(fn) {
        if (!this.passingState)
            return;
        this.passingState = false;
        await fn();
    }
}
exports.MiddlewareToken = MiddlewareToken;
class Middleware {
    constructor() {
        this.segments = [];
    }
    async handle(arg, token) {
        let accValue = arg;
        let next = (value) => {
            if (value) {
                accValue = value;
            }
            return token.next();
        };
        for (let segment of this.segments) {
            await token.complete(() => segment.fn(accValue, next));
        }
    }
    add(fn) {
        let segment = {
            id: (0, crypto_1.randomUUID)(),
            fn,
        };
        this.segments.push(segment);
        return segment;
    }
    remove(segment) {
        let index = this.segments.findIndex(s => s.id === segment.id);
        if (index === -1) {
            return false;
        }
        this.segments.splice(index, 1);
        return true;
    }
}
exports.Middleware = Middleware;
